@@ -752,32 +752,52 @@ class BIDSLayout(object):
             for name, val in filters.items():
                 tag_alias = aliased(Tag)
 
-                if isinstance(val, (list, tuple)) and len(val) == 1:
-                    val = val[0]
-
-                join_method = query.join
-
-                if val is None or val == Query.NONE:
-                    join_method = query.outerjoin
-                    val_clause = tag_alias._value.is_(None)
-                elif val == Query.OPTIONAL:
+                val_list = list(listify(val)) if val is not None else [None]
+                if not val_list:
                     continue
-                elif val == Query.ANY:
-                    val_clause = tag_alias._value.isnot(None)
-                elif regex:
-                    if isinstance(val, (list, tuple)):
-                        val_clause = sa.or_(*[
-                            tag_alias._value.op('REGEXP')(str(v))
-                            for v in val
-                        ])
-                    else:
-                        val_clause = tag_alias._value.op('REGEXP')(str(val))
-                else:
-                    vals = listify(val)
-                    if isinstance(vals[0], int):
-                        val_clause = cast(tag_alias._value, sa.Integer).in_(vals)
-                    else:
-                        val_clause = tag_alias._value.in_(vals)
+
+                if Query.OPTIONAL in val_list:
+                    continue
+
+                none = required = False
+                if None in val_list:
+                    none = True
+                    val_list.remove(None)
+                if Query.NONE in val_list:
+                    none = True
+                    val_list.remove(Query.NONE)
+                if Query.REQUIRED in val_list:
+                    required = True
+                    val_list.remove(Query.REQUIRED)
+
+                if none and required:
+                    # Always true, apply no filter
+                    continue
+
+                # Baseline, use join, start accumulating clauses
+                join_method = query.join
+                val_clauses = []
+
+                # NONE and REQUIRED get special treatment
+                if none:
+                    join_method = query.outerjoin
+                    val_clauses.append(tag_alias._value.is_(None))
+                if required:
+                    val_clauses.append(tag_alias._value.isnot(None))
+
+                # Any remaining values
+                if regex:
+                    val_clauses.extend([tag_alias._value.op('REGEXP')(str(v))
+                                        for v in val_list])
+                elif val_list:
+                    _value = tag_alias._value
+                    if isinstance(val_list[0], int):
+                        _value = cast(tag_alias._value, sa.Integer)
+
+                    val_clauses.append(_value.in_(val_list))
+
+                # Looking for intersection with list of vals, so use OR
+                val_clause = sa.or_(*val_clauses) if len(val_clauses) > 1 else val_clauses[0]
 
                 query = join_method(
                     tag_alias,
